
module Acquia
  class Cloud
    class Api
      API_VERSION = 'v1'
      BASE_URL = 'https://cloudapi.acquia.com'

      attr_reader :credentials

      def initialize(args = {})
        @acquia = Faraday.new(:url => 'https://cloudapi.acquia.com') do |client|
          client.request :url_encoded
          client.adapter Faraday.default_adapter

          # Log request and response to STDOUT.
          # client.use Faraday::Response::Logger

          # Raise errors on HTTP error codes.
          client.use Faraday::Response::RaiseError
        end

        @credentials = Credentials.new(args[:credentials])
        raise 'Unable to determine your Acquia Cloud credentials.' \
          unless @credentials.defined?
        @acquia.basic_auth @credentials.email, @credentials.key
      end

      def get(url = nil, params = nil, headers = nil, &block)
        request :get, url, params, headers, &block
      end


      def post(url = nil, body = nil, headers = nil, &block)
        request :post, url, body.nil? ? body : body.to_json, headers, &block
      end

      def delete(url = nil, params = nil, headers = nil, &block)
        request :delete, url, params, headers, &block
      end

      protected

      def request(method, url = nil, arg2 = nil, headers = nil, &block)
        response = @acquia.method(method).call "/#{API_VERSION}#{url}.json", arg2, headers, &block
        JSON.load(response.body)
      end
    end
  end
end
