require 'acquia/cloud/entity'

module Acquia
  class Cloud
    class Site < Entity
      attr_reader :name

      def initialize(cloud, name)
        @cloud = cloud
        @name = name
        @url = "/sites/#{name}"
      end

      def name
        data['name']
      end

      def vcs_type
        data['vcs_type'].to_sym
      end

      def vcs_url
        data['vcs_url']
      end

      def production_mode
        data['production_mode'].to_i != 0
      end

      def unix_username
        data['unix_username']
      end

      def title
        data['title']
      end

      def uuid
        data['uuid']
      end

      def copy_files(from, to)
        Task.new @cloud, @name, @cloud.api.post("#{@url}/files-copy/#{from}/#{to}")
      end

      def environments
        @cloud.api.get("#{@url}/envs").map do |environment|
          Environment.new(@cloud, @name, environment)
        end
      end

      def environment(name)
        Environment.new(@cloud, @name, {'name' => name}).refresh
      end

      def databases
        @cloud.api.get("#{@url}/dbs").map do |db|
          Database.new(@cloud, @name, db)
        end
      end

      def database(name)
        Database.new(@cloud, @name, {'name' => name}).refresh
      end

      def tasks
        @cloud.api.get("#{@url}/tasks").map do |task|
          Task.new(@cloud, @name, task)
        end
      end

      def task(id)
        Task.new(@cloud, @name, {'id' => id}).refresh
      end
    end
  end
end
